#
# PySNMP MIB module DS0-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DS0-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:10:48 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, SingleValueConstraint, ConstraintsIntersection, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "SingleValueConstraint", "ConstraintsIntersection", "ConstraintsUnion", "ValueRangeConstraint")
( InterfaceIndex, ifIndex, InterfaceIndexOrZero, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex", "InterfaceIndexOrZero")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( Integer32, MibScalar, MibTable, MibTableRow, MibTableColumn, MibIdentifier, Unsigned32, Gauge32, ModuleIdentity, transmission, Counter64, iso, IpAddress, NotificationType, Bits, ObjectIdentity, Counter32, TimeTicks, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Integer32", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "MibIdentifier", "Unsigned32", "Gauge32", "ModuleIdentity", "transmission", "Counter64", "iso", "IpAddress", "NotificationType", "Bits", "ObjectIdentity", "Counter32", "TimeTicks")
( DisplayString, TextualConvention, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "DisplayString", "TextualConvention", "TruthValue")
ds0 = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 81)).setRevisions(("1998-05-24 20:10",))
if mibBuilder.loadTexts: ds0.setLastUpdated('9807161630Z')
if mibBuilder.loadTexts: ds0.setOrganization('IETF Trunk MIB Working Group')
if mibBuilder.loadTexts: ds0.setContactInfo('        David Fowler\n\n          Postal: Newbridge Networks Corporation\n                  600 March Road\n                  Kanata, Ontario, Canada K2K 2E6\n\n                  Tel: +1 613 591 3600\n                  Fax: +1 613 599 3619\n\n          E-mail: davef@newbridge.com')
if mibBuilder.loadTexts: ds0.setDescription('The MIB module to describe\n             DS0 interfaces objects.')
dsx0ConfigTable = MibTable((1, 3, 6, 1, 2, 1, 10, 81, 1), )
if mibBuilder.loadTexts: dsx0ConfigTable.setDescription('The DS0 Configuration table.')
dsx0ConfigEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 81, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: dsx0ConfigEntry.setDescription('An entry in the DS0 Configuration table.  There\n               is an entry in this table for each DS0 interface.')
dsx0Ds0ChannelNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,31))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0Ds0ChannelNumber.setDescription('This object indicates the channel number of the\n               ds0 on its DS1/E1.')
dsx0RobbedBitSignalling = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 2), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0RobbedBitSignalling.setDescription('This object indicates if Robbed Bit Signalling is\n               turned on or off for a given ds0.  This only\n               applies to DS0s on a DS1 link.  For E1 links the\n               value is always off (false).')
dsx0CircuitIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 3), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0CircuitIdentifier.setDescription("This object contains the transmission vendor's\n               circuit identifier, for the purpose of\n               facilitating troubleshooting.")
dsx0IdleCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0IdleCode.setDescription('This object contains the code transmitted in the\n               ABCD bits when the ds0 is not connected and\n               dsx0TransmitCodesEnable is enabled.  The object is\n               a bitmap and the various bit positions are:\n                     1     D bit\n                     2     C bit\n                     4     B bit\n                     8     A bit')
dsx0SeizedCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0SeizedCode.setDescription('This object contains the code transmitted in the\n               ABCD bits when the ds0 is connected and\n               dsx0TransmitCodesEnable is enabled.  The object is\n               a bitmap and the various bit positions are:\n                     1     D bit\n                     2     C bit\n                     4     B bit\n                     8     A bit')
dsx0ReceivedCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0ReceivedCode.setDescription('This object contains the code being received in\n               the ABCD bits.  The object is a bitmap and the\n               various bit positions are:\n                     1     D bit\n                     2     C bit\n                     4     B bit\n                     8     A bit')
dsx0TransmitCodesEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 7), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: dsx0TransmitCodesEnable.setDescription('This object determines if the idle and seized\n               codes are transmitted. If the value of this object\n               is true then the codes are transmitted.')
dsx0Ds0BundleMappedIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 1, 1, 8), InterfaceIndexOrZero()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0Ds0BundleMappedIfIndex.setDescription('This object indicates the ifIndex value assigned\n               by the agent for the ds0Bundle(82) ifEntry to\n               which the given ds0(81) ifEntry may belong.\n\n               If the given ds0(81) ifEntry does not belong to\n               any ds0Bundle(82) ifEntry, then this object has a\n               value of zero.\n\n               While this object provides information that can\n               also be found in the ifStackTable, it provides\n               this same information with a single table lookup,\n               rather than by walking the ifStackTable to find\n               the possibly non-existent ds0Bundle(82) ifEntry\n               that may be stacked above the given ds0(81)\n               ifTable entry.')
dsx0ChanMappingTable = MibTable((1, 3, 6, 1, 2, 1, 10, 81, 3), )
if mibBuilder.loadTexts: dsx0ChanMappingTable.setDescription('The DS0 Channel Mapping table.  This table maps a\n               DS0 channel number on a particular DS1/E1 into an\n               ifIndex.')
dsx0ChanMappingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 81, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DS0-MIB", "dsx0Ds0ChannelNumber"))
if mibBuilder.loadTexts: dsx0ChanMappingEntry.setDescription('An entry in the DS0 Channel Mapping table.  There\n               is an entry in this table corresponding to each\n               ds0 ifEntry within any interface that is\n               channelized to the individual ds0 ifEntry level.\n\n               This table is intended to facilitate mapping from\n               channelized interface / channel number to DS0\n               ifEntry.  (e.g. mapping (DS1 ifIndex, DS0 Channel\n               Number) -> ifIndex)\n\n               While this table provides information that can\n               also be found in the ifStackTable and\n               dsx0ConfigTable, it provides this same information\n               with a single table lookup, rather than by walking\n               the ifStackTable to find the various constituent\n               ds0 ifTable entries, and testing various\n               dsx0ConfigTable entries to check for the entry\n               with the applicable DS0 channel number.')
dsx0ChanMappedIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 81, 3, 1, 1), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: dsx0ChanMappedIfIndex.setDescription('This object indicates the ifIndex value assigned\n               by the agent for the individual ds0 ifEntry that\n               corresponds to the given DS0 channel number\n               (specified by the INDEX element\n               dsx0Ds0ChannelNumber) of the given channelized\n               interface (specified by INDEX element ifIndex).')
ds0Conformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 81, 2))
ds0Groups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 81, 2, 1))
ds0Compliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 81, 2, 2))
ds0Compliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 81, 2, 2, 1)).setObjects(*(("DS0-MIB", "ds0ConfigGroup"),))
if mibBuilder.loadTexts: ds0Compliance.setDescription('The compliance statement for DS0 interfaces.')
ds0ConfigGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 81, 2, 1, 1)).setObjects(*(("DS0-MIB", "dsx0Ds0ChannelNumber"), ("DS0-MIB", "dsx0RobbedBitSignalling"), ("DS0-MIB", "dsx0CircuitIdentifier"), ("DS0-MIB", "dsx0IdleCode"), ("DS0-MIB", "dsx0SeizedCode"), ("DS0-MIB", "dsx0ReceivedCode"), ("DS0-MIB", "dsx0TransmitCodesEnable"), ("DS0-MIB", "dsx0Ds0BundleMappedIfIndex"), ("DS0-MIB", "dsx0ChanMappedIfIndex"),))
if mibBuilder.loadTexts: ds0ConfigGroup.setDescription('A collection of objects providing configuration\n               information applicable to all DS0 interfaces.')
mibBuilder.exportSymbols("DS0-MIB", dsx0ChanMappingTable=dsx0ChanMappingTable, dsx0ChanMappedIfIndex=dsx0ChanMappedIfIndex, dsx0RobbedBitSignalling=dsx0RobbedBitSignalling, dsx0ChanMappingEntry=dsx0ChanMappingEntry, dsx0ConfigEntry=dsx0ConfigEntry, dsx0Ds0ChannelNumber=dsx0Ds0ChannelNumber, dsx0SeizedCode=dsx0SeizedCode, ds0Compliance=ds0Compliance, ds0Conformance=ds0Conformance, dsx0ConfigTable=dsx0ConfigTable, dsx0CircuitIdentifier=dsx0CircuitIdentifier, dsx0TransmitCodesEnable=dsx0TransmitCodesEnable, dsx0ReceivedCode=dsx0ReceivedCode, ds0Groups=ds0Groups, ds0Compliances=ds0Compliances, ds0=ds0, dsx0IdleCode=dsx0IdleCode, PYSNMP_MODULE_ID=ds0, dsx0Ds0BundleMappedIfIndex=dsx0Ds0BundleMappedIfIndex, ds0ConfigGroup=ds0ConfigGroup)



#
# PySNMP MIB module ISDN-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ISDN-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:19:03 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, SingleValueConstraint, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( IANAifType, ) = mibBuilder.importSymbols("IANAifType-MIB", "IANAifType")
( InterfaceIndex, ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "InterfaceIndex", "ifIndex")
( ObjectGroup, NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ObjectGroup", "NotificationGroup", "ModuleCompliance")
( TimeTicks, MibIdentifier, Counter64, Unsigned32, transmission, iso, Integer32, ObjectIdentity, IpAddress, Gauge32, Counter32, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Bits, ModuleIdentity, ) = mibBuilder.importSymbols("SNMPv2-SMI", "TimeTicks", "MibIdentifier", "Counter64", "Unsigned32", "transmission", "iso", "Integer32", "ObjectIdentity", "IpAddress", "Gauge32", "Counter32", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Bits", "ModuleIdentity")
( TimeStamp, TruthValue, TestAndIncr, DisplayString, TextualConvention, RowStatus, ) = mibBuilder.importSymbols("SNMPv2-TC", "TimeStamp", "TruthValue", "TestAndIncr", "DisplayString", "TextualConvention", "RowStatus")
isdnMib = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 20))
if mibBuilder.loadTexts: isdnMib.setLastUpdated('9609231642Z')
if mibBuilder.loadTexts: isdnMib.setOrganization('IETF ISDN MIB Working Group')
if mibBuilder.loadTexts: isdnMib.setContactInfo('        Guenter Roeck\n             Postal: cisco Systems\n                     170 West Tasman Drive\n                     San Jose, CA 95134\n                     U.S.A.\n             Phone:  +1 408 527 3143\n             E-mail: groeck@cisco.com')
if mibBuilder.loadTexts: isdnMib.setDescription('The MIB module to describe the\n             management of ISDN interfaces.')
class IsdnSignalingProtocol(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25,))
    namedValues = NamedValues(("other", 1), ("dss1", 2), ("etsi", 3), ("dass2", 4), ("ess4", 5), ("ess5", 6), ("dms100", 7), ("dms250", 8), ("ni1", 9), ("ni2", 10), ("ni3", 11), ("vn2", 12), ("vn3", 13), ("vn4", 14), ("vn6", 15), ("kdd", 16), ("ins64", 17), ("ins1500", 18), ("itr6", 19), ("cornet", 20), ("ts013", 21), ("ts014", 22), ("qsig", 23), ("swissnet2", 24), ("swissnet3", 25),)

isdnMibObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1))
isdnBasicRateGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1, 1))
isdnBasicRateTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1), )
if mibBuilder.loadTexts: isdnBasicRateTable.setDescription('Table containing configuration and operational\n             parameters for all physical Basic Rate\n             interfaces on this managed device.')
isdnBasicRateEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: isdnBasicRateEntry.setDescription('An entry in the ISDN Basic Rate Table.')
isdnBasicRateIfType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(75, 76,))).clone(namedValues=NamedValues(("isdns", 75), ("isdnu", 76),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnBasicRateIfType.setDescription("The physical interface type. For 'S/T' interfaces,\n             also called 'Four-wire Basic Access Interface',\n             the value of this object is isdns(75).\n             For 'U' interfaces, also called 'Two-wire Basic\n             Access Interface', the value of this object is\n             isdnu(76).")
isdnBasicRateLineTopology = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("pointToPoint", 1), ("pointToMultipoint", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnBasicRateLineTopology.setDescription('The line topology to be used for this interface.\n             Note that setting isdnBasicRateIfType to isdns(75)\n             does not necessarily mean a line topology of\n             point-to-multipoint.')
isdnBasicRateIfMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("te", 1), ("nt", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnBasicRateIfMode.setDescription('The physical interface mode. For TE mode, the value\n             of this object is te(1). For NT mode, the value\n             of this object is nt(2).')
isdnBasicRateSignalMode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("active", 1), ("inactive", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnBasicRateSignalMode.setDescription('The signaling channel operational mode for this interface.\n             If active(1) there is a signaling channel on this\n             interface. If inactive(2) a signaling channel is\n             not available.')
isdnBearerGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1, 2))
isdnBearerTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1), )
if mibBuilder.loadTexts: isdnBearerTable.setDescription('This table defines port specific operational, statistics\n             and active call data for ISDN B channels. Each entry\n             in this table describes one B (bearer) channel.')
isdnBearerEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: isdnBearerEntry.setDescription('Operational and statistics information relating to\n             one port. A port is a single B channel.')
isdnBearerChannelType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("dialup", 1), ("leased", 2),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnBearerChannelType.setDescription('The B channel type. If the B channel is connected\n             to a dialup line, this object has a value of\n             dialup(1). In this case, it is controlled by\n             an associated signaling channel. If the B channel\n             is connected to a leased line, this object has\n             a value of leased(2). For leased line B channels, there\n             is no signaling channel control available.')
isdnBearerOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("idle", 1), ("connecting", 2), ("connected", 3), ("active", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerOperStatus.setDescription('The current call control state for this port.\n             idle(1):       The B channel is idle.\n                            No call or call attempt is going on.\n             connecting(2): A connection attempt (outgoing call)\n                            is being made on this interface.\n             connected(3):  An incoming call is in the process\n                            of validation.\n             active(4):     A call is active on this interface.')
isdnBearerChannelNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,30))).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerChannelNumber.setDescription('The identifier being used by a signaling protocol\n             to identify this B channel, also referred to as\n             B channel number. If the Agent also supports the DS0 MIB,\n             the values of isdnBearerChannelNumber and dsx0Ds0Number\n             must be identical for a given B channel.')
isdnBearerPeerAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 4), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerPeerAddress.setDescription("The ISDN address the current or last call is or was\n             connected to.\n\n             In some cases, the format of this information can not\n             be predicted, since it largely depends on the type\n             of switch or PBX the device is connected to. Therefore,\n             the detailed format of this information is not\n             specified and is implementation dependent.\n\n             If possible, the agent should supply this information\n             using the E.164 format. In this case, the number must\n             start with '+'. Otherwise, IA5 number digits must be used.\n\n             If the peer ISDN address is not available,\n             this object has a length of zero.")
isdnBearerPeerSubAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 5), DisplayString()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerPeerSubAddress.setDescription('The ISDN subaddress the current or last call is or was\n             connected to.\n\n             The subaddress is an user supplied string of up to 20\n             IA5 characters and is transmitted transparently through\n             the network.\n\n             If the peer subaddress is not available, this object\n             has a length of zero.')
isdnBearerCallOrigin = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 6), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("unknown", 1), ("originate", 2), ("answer", 3), ("callback", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerCallOrigin.setDescription('The call origin for the current or last call. If since\n             system startup there was no call on this interface,\n             this object has a value of unknown(1).')
isdnBearerInfoType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9,))).clone(namedValues=NamedValues(("unknown", 1), ("speech", 2), ("unrestrictedDigital", 3), ("unrestrictedDigital56", 4), ("restrictedDigital", 5), ("audio31", 6), ("audio7", 7), ("video", 8), ("packetSwitched", 9),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerInfoType.setDescription("The Information Transfer Capability for the current\n             or last call.\n\n             speech(2) refers to a non-data connection, whereas\n             audio31(6) and audio7(7) refer to data mode connections.\n\n             Note that Q.931, chapter 4.5.5, originally defined\n             audio7(7) as '7 kHz audio' and now defines it as\n             'Unrestricted digital information with tones/\n             announcements'.\n\n             If since system startup there has been no call on this\n             interface, this object has a value of unknown(1).")
isdnBearerMultirate = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerMultirate.setDescription('This flag indicates if the current or last call used\n             multirate. The actual information transfer rate,\n             in detail specified in octet 4.1 (rate multiplier),\n             is the sum of all B channel ifSpeed values for\n             the hyperchannel.\n\n             If since system startup there was no call on this\n             interface, this object has a value of false(2).')
isdnBearerCallSetupTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 9), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerCallSetupTime.setDescription('The value of sysUpTime when the ISDN setup message for\n             the current or last call was sent or received. If since\n             system startup there has been no call on this interface,\n             this object has a value of zero.')
isdnBearerCallConnectTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 10), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerCallConnectTime.setDescription('The value of sysUpTime when the ISDN connect message for\n             the current or last call was sent or received. If since\n             system startup there has been no call on this interface,\n             this object has a value of zero.')
isdnBearerChargedUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 2, 1, 1, 11), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnBearerChargedUnits.setDescription('The number of charged units for the current or last\n             connection. For incoming calls or if charging information\n             is not supplied by the switch, the value of this object\n             is zero.')
isdnSignalingGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1, 3))
isdnSignalingGetIndex = MibScalar((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 1), TestAndIncr()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnSignalingGetIndex.setDescription('The recommended procedure for selecting a new index for\n             isdnSignalingTable row creation is to GET the value of\n             this object, and then to SET the object with the same\n             value. If the SET operation succeeds, the manager can use\n             this value as an index to create a new row in this table.')
isdnSignalingTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2), )
if mibBuilder.loadTexts: isdnSignalingTable.setDescription('ISDN signaling table containing configuration and\n             operational parameters for all ISDN signaling\n             channels on this managed device.')
isdnSignalingEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1), ).setIndexNames((0, "ISDN-MIB", "isdnSignalingIndex"))
if mibBuilder.loadTexts: isdnSignalingEntry.setDescription('An entry in the ISDN Signaling Table. To create a new\n             entry, only isdnSignalingProtocol needs to be specified\n             before isdnSignalingStatus can become active(1).')
isdnSignalingIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: isdnSignalingIndex.setDescription('The index value which uniquely identifies an entry\n             in the isdnSignalingTable.')
isdnSignalingIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 2), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSignalingIfIndex.setDescription('The ifIndex value of the interface associated with this\n             signaling channel.')
isdnSignalingProtocol = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 3), IsdnSignalingProtocol()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingProtocol.setDescription('The particular protocol type supported by the\n             switch providing access to the ISDN network\n             to which this signaling channel is connected.')
isdnSignalingCallingAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 4), DisplayString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingCallingAddress.setDescription("The ISDN Address to be assigned to this signaling\n             channel. More specifically, this is the 'Calling Address\n             information element' as being passed to the switch\n             in outgoing call setup messages.\n\n             It can be an EAZ (1TR6), a calling number (DSS1, ETSI)\n             or any other number necessary to identify a signaling\n             interface. If there is no such number defined or required,\n             this is a zero length string. It is represented in\n             DisplayString form.\n\n             Incoming calls can also be identified by this number.\n             If the Directory Number, i.e. the Called Number in\n             incoming calls, is different to this number, the\n             isdnDirectoryTable has to be used to specify all\n             possible Directory Numbers.\n\n             The format of this information largely depends on the type\n             of switch or PBX the device is connected to. Therefore,\n             the detailed format of this information is not\n             specified and is implementation dependent.\n\n             If possible, the agent should implement this information\n             using the E.164 number format. In this case, the number\n             must start with '+'. Otherwise, IA5 number digits must\n             be used.")
isdnSignalingSubAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 5), DisplayString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingSubAddress.setDescription('Supplementary information to the ISDN address assigned\n             to this signaling channel. Usually, this is the\n             subaddress as defined in Q.931.\n             If there is no such number defined or required, this is\n             a zero length string.\n             The subaddress is used for incoming calls as well as\n             for outgoing calls.\n             The subaddress is an user supplied string of up to 20\n             IA5 characters and is transmitted transparently through\n             the network.')
isdnSignalingBchannelCount = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingBchannelCount.setDescription('The total number of B channels (bearer channels)\n             managed by this signaling channel. The default value\n             of this object depends on the physical interface type\n             and is either 2 for Basic Rate interfaces or\n             24 (30) for Primary Rate interfaces.')
isdnSignalingInfoTrapEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("enabled", 1), ("disabled", 2),)).clone('disabled')).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingInfoTrapEnable.setDescription('Indicates whether isdnMibCallInformation traps\n             should be generated for calls on this signaling\n             channel.')
isdnSignalingStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 2, 1, 8), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnSignalingStatus.setDescription('This object is used to create and delete rows in the\n             isdnSignalingTable.')
isdnSignalingStatsTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3), )
if mibBuilder.loadTexts: isdnSignalingStatsTable.setDescription('ISDN signaling table containing statistics\n             information for all ISDN signaling channels\n             on this managed device.\n             Only statistical information which is not already being\n             counted in the ifTable is being defined in this table.')
isdnSignalingStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1), )
isdnSignalingEntry.registerAugmentions(("ISDN-MIB", "isdnSignalingStatsEntry"))
isdnSignalingStatsEntry.setIndexNames(*isdnSignalingEntry.getIndexNames())
if mibBuilder.loadTexts: isdnSignalingStatsEntry.setDescription('An entry in the ISDN Signaling statistics Table.')
isdnSigStatsInCalls = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSigStatsInCalls.setDescription('The number of incoming calls on this interface.')
isdnSigStatsInConnected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSigStatsInConnected.setDescription('The number of incoming calls on this interface\n             which were actually connected.')
isdnSigStatsOutCalls = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSigStatsOutCalls.setDescription('The number of outgoing calls on this interface.')
isdnSigStatsOutConnected = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSigStatsOutConnected.setDescription('The number of outgoing calls on this interface\n             which were actually connected.')
isdnSigStatsChargedUnits = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 3, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnSigStatsChargedUnits.setDescription("The number of charging units on this interface since\n             system startup.\n             Only the charging units applying to the local interface,\n             i.e. for originated calls or for calls with 'Reverse\n             charging' being active, are counted here.")
isdnLapdTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4), )
if mibBuilder.loadTexts: isdnLapdTable.setDescription('Table containing configuration and statistics\n             information for all LAPD (D channel Data Link)\n             interfaces on this managed device.\n             Only statistical information which is not already being\n             counted in the ifTable is being defined in this table.')
isdnLapdEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: isdnLapdEntry.setDescription('An entry in the LAPD Table.')
isdnLapdPrimaryChannel = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4, 1, 1), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnLapdPrimaryChannel.setDescription('If set to true(1), this D channel is the designated\n             primary D channel if D channel backup is active.\n             There must be exactly one primary D channel\n             configured. If D channel backup is not used, this\n             object has a value of true(1).')
isdnLapdOperStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3,))).clone(namedValues=NamedValues(("inactive", 1), ("l1Active", 2), ("l2Active", 3),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnLapdOperStatus.setDescription('The operational status of this interface:\n\n             inactive  all layers are inactive\n             l1Active  layer 1 is activated,\n                       layer 2 datalink not established\n             l2Active  layer 1 is activated,\n                       layer 2 datalink established.')
isdnLapdPeerSabme = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnLapdPeerSabme.setDescription('The number of peer SABME frames received on this\n             interface. This is the number of peer-initiated\n             new connections on this interface.')
isdnLapdRecvdFrmr = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 3, 4, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnLapdRecvdFrmr.setDescription('The number of LAPD FRMR response frames received.\n             This is the number of framing errors on this\n             interface.')
isdnEndpointGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1, 4))
isdnEndpointGetIndex = MibScalar((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 1), TestAndIncr()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: isdnEndpointGetIndex.setDescription('The recommended procedure for selecting a new index for\n             isdnEndpointTable row creation is to GET the value of\n             this object, and then to SET the object with the same\n             value. If the SET operation succeeds, the manager can use\n             this value as an index to create a new row in this table.')
isdnEndpointTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2), )
if mibBuilder.loadTexts: isdnEndpointTable.setDescription('Table containing configuration for Terminal\n             Endpoints.')
isdnEndpointEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1), ).setIndexNames((0, "ISDN-MIB", "isdnEndpointIndex"))
if mibBuilder.loadTexts: isdnEndpointEntry.setDescription('An entry in the Terminal Endpoint Table. The value\n             of isdnEndpointIfType must be supplied for a row\n             in this table to become active.')
isdnEndpointIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: isdnEndpointIndex.setDescription('The index value which uniquely identifies an entry\n             in the isdnEndpointTable.')
isdnEndpointIfIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 2), InterfaceIndex()).setMaxAccess("readonly")
if mibBuilder.loadTexts: isdnEndpointIfIndex.setDescription('The ifIndex value of the interface associated with this\n             Terminal Endpoint.')
isdnEndpointIfType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 3), IANAifType()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnEndpointIfType.setDescription('The interface type for this Terminal Endpoint.\n             Interface types of x25ple(40) and isdn(63) are allowed.\n             The interface type is identical to the value of\n             ifType in the associated ifEntry.')
isdnEndpointTeiType = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 4), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("dynamic", 1), ("static", 2),))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnEndpointTeiType.setDescription('The type of TEI (Terminal Endpoint Identifier)\n             used for this Terminal Endpoint. In case of dynamic(1),\n             the TEI value is selected by the switch. In\n             case of static(2), a valid TEI value has to be\n             entered in the isdnEndpointTeiValue object.\n             The default value for this object depends on the\n             interface type as well as the Terminal Endpoint type.\n             On Primary Rate interfaces the default value is\n             static(2). On Basic Rate interfaces the default value\n             is dynamic(1) for isdn(63) Terminal Endpoints and\n             static(2) for x25ple(40) Terminal Endpoints.')
isdnEndpointTeiValue = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,255))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnEndpointTeiValue.setDescription('The TEI (Terminal Endpoint Identifier) value\n             for this Terminal Endpoint. If isdnEndpointTeiType\n             is set to static(2), valid numbers are 0..63,\n             while otherwise the value is set internally.\n             The default value of this object is 0 for static\n             TEI assignment.\n             The default value for dynamic TEI assignment is also\n             0 as long as no TEI has been assigned. After TEI\n             assignment, the assigned TEI value is returned.')
isdnEndpointSpid = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 6), DisplayString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnEndpointSpid.setDescription('The Service profile IDentifier (SPID) information\n             for this Terminal Endpoint.\n\n             The SPID is composed of 9-20 numeric characters.\n\n             This information has to be defined in addition to\n             the local number for some switch protocol types,\n             e.g. Bellcore NI-1 and NI-2.\n\n             If this object is not required, it is a\n             zero length string.')
isdnEndpointStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 4, 2, 1, 7), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnEndpointStatus.setDescription('This object is used to create and delete rows in the\n             isdnEndpointTable.')
isdnDirectoryGroup = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 1, 5))
isdnDirectoryTable = MibTable((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1), )
if mibBuilder.loadTexts: isdnDirectoryTable.setDescription('Table containing Directory Numbers.')
isdnDirectoryEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1, 1), ).setIndexNames((0, "ISDN-MIB", "isdnDirectoryIndex"))
if mibBuilder.loadTexts: isdnDirectoryEntry.setDescription('An entry in the Directory Number Table. All objects\n             in an entry must be set for a new row to become active.')
isdnDirectoryIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647)))
if mibBuilder.loadTexts: isdnDirectoryIndex.setDescription('The index value which uniquely identifies an entry\n             in the isdnDirectoryTable.')
isdnDirectoryNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1, 1, 2), DisplayString()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnDirectoryNumber.setDescription("A Directory Number. Directory Numbers are used\n             to identify incoming calls on the signaling\n             channel given in isdnDirectorySigIndex.\n\n             The format of this information largely depends on the type\n             of switch or PBX the device is connected to. Therefore,\n             the detailed format of this information is not\n             specified and is implementation dependent.\n\n             If possible, the agent should implement this information\n             using the E.164 number format. In this case, the number\n             must start with '+'. Otherwise, IA5 number digits must\n             be used.")
isdnDirectorySigIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,2147483647))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnDirectorySigIndex.setDescription('An index pointing to an ISDN signaling channel.\n             Incoming calls are accepted on this\n             signaling channel if the isdnDirectoryNumber is\n             presented as Called Number in the SETUP message.')
isdnDirectoryStatus = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 20, 1, 5, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: isdnDirectoryStatus.setDescription('This object is used to create and delete rows in the\n             isdnDirectoryTable.')
isdnMibTrapPrefix = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 2))
isdnMibTraps = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 2, 0))
isdnMibCallInformation = NotificationType((1, 3, 6, 1, 2, 1, 10, 20, 2, 0, 1)).setObjects(*(("ISDN-MIB", "ifIndex"), ("ISDN-MIB", "isdnBearerOperStatus"), ("ISDN-MIB", "isdnBearerPeerAddress"), ("ISDN-MIB", "isdnBearerPeerSubAddress"), ("ISDN-MIB", "isdnBearerCallSetupTime"), ("ISDN-MIB", "isdnBearerInfoType"), ("ISDN-MIB", "isdnBearerCallOrigin"),))
if mibBuilder.loadTexts: isdnMibCallInformation.setDescription('This trap/inform is sent to the manager under the\n             following condidions:\n             - on incoming calls for each call which is rejected for\n               policy reasons (e.g. unknown neighbor or access\n               violation)\n             - on outgoing calls whenever a call attempt is determined\n               to have ultimately failed. In the event that call retry\n               is active, then this will be after all retry attempts\n               have failed.\n             - whenever a call connects. In this case, the object\n               isdnBearerCallConnectTime should be included in the\n               trap.\n\n             Only one such trap is sent in between successful or\n             unsuccessful call attempts from or to a single neighbor;\n             subsequent call attempts result in no trap.\n\n             If the Dial Control MIB objects dialCtlNbrCfgId and\n             dialCtlNbrCfgIndex are known by the entity generating\n             this trap, both objects should be included in the trap\n             as well. The receipt of this trap with no dial neighbor\n             information indicates that the manager must poll the\n             callHistoryTable of the Dial Control MIB to see what\n             changed.')
isdnMibConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 3))
isdnMibCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 3, 1))
isdnMibGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 20, 3, 2))
isdnMibCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 20, 3, 1, 1)).setObjects(*(("ISDN-MIB", "isdnMibSignalingGroup"), ("ISDN-MIB", "isdnMibBearerGroup"), ("ISDN-MIB", "isdnMibBasicRateGroup"), ("ISDN-MIB", "isdnMibEndpointGroup"), ("ISDN-MIB", "isdnMibDirectoryGroup"),))
if mibBuilder.loadTexts: isdnMibCompliance.setDescription('The compliance statement for entities which implement\n             the ISDN MIB.')
isdnMibBasicRateGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 20, 3, 2, 1)).setObjects(*(("ISDN-MIB", "isdnBasicRateIfType"), ("ISDN-MIB", "isdnBasicRateLineTopology"), ("ISDN-MIB", "isdnBasicRateIfMode"), ("ISDN-MIB", "isdnBasicRateSignalMode"),))
if mibBuilder.loadTexts: isdnMibBasicRateGroup.setDescription('A collection of objects required for ISDN Basic Rate\n             physical interface configuration and statistics.')
isdnMibBearerGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 20, 3, 2, 2)).setObjects(*(("ISDN-MIB", "isdnBearerChannelType"), ("ISDN-MIB", "isdnBearerOperStatus"), ("ISDN-MIB", "isdnBearerChannelNumber"), ("ISDN-MIB", "isdnBearerPeerAddress"), ("ISDN-MIB", "isdnBearerPeerSubAddress"), ("ISDN-MIB", "isdnBearerCallOrigin"), ("ISDN-MIB", "isdnBearerInfoType"), ("ISDN-MIB", "isdnBearerMultirate"), ("ISDN-MIB", "isdnBearerCallSetupTime"), ("ISDN-MIB", "isdnBearerCallConnectTime"), ("ISDN-MIB", "isdnBearerChargedUnits"),))
if mibBuilder.loadTexts: isdnMibBearerGroup.setDescription('A collection of objects required for ISDN Bearer channel\n             control and statistics.')
isdnMibSignalingGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 20, 3, 2, 3)).setObjects(*(("ISDN-MIB", "isdnSignalingGetIndex"), ("ISDN-MIB", "isdnSignalingIfIndex"), ("ISDN-MIB", "isdnSignalingProtocol"), ("ISDN-MIB", "isdnSignalingCallingAddress"), ("ISDN-MIB", "isdnSignalingSubAddress"), ("ISDN-MIB", "isdnSignalingBchannelCount"), ("ISDN-MIB", "isdnSignalingInfoTrapEnable"), ("ISDN-MIB", "isdnSignalingStatus"), ("ISDN-MIB", "isdnSigStatsInCalls"), ("ISDN-MIB", "isdnSigStatsInConnected"), ("ISDN-MIB", "isdnSigStatsOutCalls"), ("ISDN-MIB", "isdnSigStatsOutConnected"), ("ISDN-MIB", "isdnSigStatsChargedUnits"), ("ISDN-MIB", "isdnLapdPrimaryChannel"), ("ISDN-MIB", "isdnLapdOperStatus"), ("ISDN-MIB", "isdnLapdPeerSabme"), ("ISDN-MIB", "isdnLapdRecvdFrmr"),))
if mibBuilder.loadTexts: isdnMibSignalingGroup.setDescription('A collection of objects required for ISDN D channel\n             configuration and statistics.')
isdnMibEndpointGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 20, 3, 2, 4)).setObjects(*(("ISDN-MIB", "isdnEndpointGetIndex"), ("ISDN-MIB", "isdnEndpointIfIndex"), ("ISDN-MIB", "isdnEndpointIfType"), ("ISDN-MIB", "isdnEndpointTeiType"), ("ISDN-MIB", "isdnEndpointTeiValue"), ("ISDN-MIB", "isdnEndpointSpid"), ("ISDN-MIB", "isdnEndpointStatus"),))
if mibBuilder.loadTexts: isdnMibEndpointGroup.setDescription('A collection of objects describing Terminal Endpoints.')
isdnMibDirectoryGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 20, 3, 2, 5)).setObjects(*(("ISDN-MIB", "isdnDirectoryNumber"), ("ISDN-MIB", "isdnDirectorySigIndex"), ("ISDN-MIB", "isdnDirectoryStatus"),))
if mibBuilder.loadTexts: isdnMibDirectoryGroup.setDescription('A collection of objects describing directory numbers.')
mibBuilder.exportSymbols("ISDN-MIB", isdnBearerGroup=isdnBearerGroup, isdnMib=isdnMib, isdnBasicRateGroup=isdnBasicRateGroup, isdnLapdRecvdFrmr=isdnLapdRecvdFrmr, PYSNMP_MODULE_ID=isdnMib, isdnBasicRateIfType=isdnBasicRateIfType, isdnEndpointGetIndex=isdnEndpointGetIndex, isdnDirectoryStatus=isdnDirectoryStatus, isdnEndpointIndex=isdnEndpointIndex, isdnDirectoryNumber=isdnDirectoryNumber, isdnSignalingProtocol=isdnSignalingProtocol, isdnBearerEntry=isdnBearerEntry, isdnBearerMultirate=isdnBearerMultirate, isdnLapdTable=isdnLapdTable, isdnSignalingGroup=isdnSignalingGroup, isdnBasicRateIfMode=isdnBasicRateIfMode, isdnEndpointSpid=isdnEndpointSpid, isdnMibSignalingGroup=isdnMibSignalingGroup, isdnBearerCallConnectTime=isdnBearerCallConnectTime, isdnSignalingStatus=isdnSignalingStatus, isdnEndpointTeiValue=isdnEndpointTeiValue, isdnMibTrapPrefix=isdnMibTrapPrefix, isdnBearerInfoType=isdnBearerInfoType, isdnLapdPrimaryChannel=isdnLapdPrimaryChannel, isdnSignalingEntry=isdnSignalingEntry, isdnMibObjects=isdnMibObjects, isdnEndpointIfType=isdnEndpointIfType, isdnBearerPeerSubAddress=isdnBearerPeerSubAddress, isdnSignalingIfIndex=isdnSignalingIfIndex, isdnSignalingBchannelCount=isdnSignalingBchannelCount, isdnDirectoryTable=isdnDirectoryTable, isdnBasicRateEntry=isdnBasicRateEntry, isdnMibCallInformation=isdnMibCallInformation, isdnSigStatsOutConnected=isdnSigStatsOutConnected, isdnEndpointStatus=isdnEndpointStatus, isdnBearerChannelNumber=isdnBearerChannelNumber, isdnMibCompliances=isdnMibCompliances, isdnMibBearerGroup=isdnMibBearerGroup, isdnSigStatsInConnected=isdnSigStatsInConnected, isdnEndpointIfIndex=isdnEndpointIfIndex, isdnBearerCallOrigin=isdnBearerCallOrigin, isdnSignalingCallingAddress=isdnSignalingCallingAddress, IsdnSignalingProtocol=IsdnSignalingProtocol, isdnBearerChannelType=isdnBearerChannelType, isdnMibGroups=isdnMibGroups, isdnBasicRateTable=isdnBasicRateTable, isdnBasicRateLineTopology=isdnBasicRateLineTopology, isdnBearerTable=isdnBearerTable, isdnEndpointTable=isdnEndpointTable, isdnEndpointEntry=isdnEndpointEntry, isdnSignalingTable=isdnSignalingTable, isdnBearerPeerAddress=isdnBearerPeerAddress, isdnSigStatsOutCalls=isdnSigStatsOutCalls, isdnMibCompliance=isdnMibCompliance, isdnDirectorySigIndex=isdnDirectorySigIndex, isdnMibBasicRateGroup=isdnMibBasicRateGroup, isdnDirectoryGroup=isdnDirectoryGroup, isdnSigStatsChargedUnits=isdnSigStatsChargedUnits, isdnMibConformance=isdnMibConformance, isdnSignalingIndex=isdnSignalingIndex, isdnMibDirectoryGroup=isdnMibDirectoryGroup, isdnSigStatsInCalls=isdnSigStatsInCalls, isdnLapdOperStatus=isdnLapdOperStatus, isdnSignalingStatsEntry=isdnSignalingStatsEntry, isdnDirectoryIndex=isdnDirectoryIndex, isdnMibEndpointGroup=isdnMibEndpointGroup, isdnMibTraps=isdnMibTraps, isdnBearerOperStatus=isdnBearerOperStatus, isdnBearerCallSetupTime=isdnBearerCallSetupTime, isdnEndpointTeiType=isdnEndpointTeiType, isdnBasicRateSignalMode=isdnBasicRateSignalMode, isdnSignalingInfoTrapEnable=isdnSignalingInfoTrapEnable, isdnSignalingGetIndex=isdnSignalingGetIndex, isdnSignalingStatsTable=isdnSignalingStatsTable, isdnEndpointGroup=isdnEndpointGroup, isdnDirectoryEntry=isdnDirectoryEntry, isdnBearerChargedUnits=isdnBearerChargedUnits, isdnSignalingSubAddress=isdnSignalingSubAddress, isdnLapdEntry=isdnLapdEntry, isdnLapdPeerSabme=isdnLapdPeerSabme)



#
# PySNMP MIB module DOCS-BPI-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/DOCS-BPI-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:09:03 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, ObjectIdentifier, Integer, ) = mibBuilder.importSymbols("ASN1", "OctetString", "ObjectIdentifier", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueRangeConstraint, ConstraintsUnion, SingleValueConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueRangeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( docsIfCmServiceId, docsIfCmtsServiceId, docsIfMib, ) = mibBuilder.importSymbols("DOCS-IF-MIB", "docsIfCmServiceId", "docsIfCmtsServiceId", "docsIfMib")
( ifIndex, ) = mibBuilder.importSymbols("IF-MIB", "ifIndex")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( Counter32, Counter64, MibIdentifier, ObjectIdentity, NotificationType, MibScalar, MibTable, MibTableRow, MibTableColumn, Gauge32, Integer32, IpAddress, Unsigned32, TimeTicks, iso, ModuleIdentity, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Counter32", "Counter64", "MibIdentifier", "ObjectIdentity", "NotificationType", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Gauge32", "Integer32", "IpAddress", "Unsigned32", "TimeTicks", "iso", "ModuleIdentity", "Bits")
( MacAddress, RowStatus, TextualConvention, DisplayString, TruthValue, DateAndTime, ) = mibBuilder.importSymbols("SNMPv2-TC", "MacAddress", "RowStatus", "TextualConvention", "DisplayString", "TruthValue", "DateAndTime")
docsBpiMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 127, 5)).setRevisions(("2001-03-13 00:00", "2000-11-03 19:30", "2000-02-16 19:30",))
if mibBuilder.loadTexts: docsBpiMIB.setLastUpdated('200103130000Z')
if mibBuilder.loadTexts: docsBpiMIB.setOrganization('IETF IPCDN Working Group')
if mibBuilder.loadTexts: docsBpiMIB.setContactInfo('Rich Woundy\n              Postal: Cisco Systems\n                      250 Apollo Drive\n                      Chelmsford, MA 01824 U.S.A.\n              Tel: +1 978 244 8000\n              E-mail: rwoundy@cisco.com\n\n              IETF IPCDN Working Group\n              General Discussion: ipcdn@ietf.org\n              Subscribe: http://www.ietf.org/mailman/listinfo/ipcdn\n              Archive: ftp://ftp.ietf.org/ietf-mail-archive/ipcdn\n              Co-chairs: Richard Woundy, rwoundy@cisco.com\n                         Andrew Valentine, a.valentine@eu.hns.com')
if mibBuilder.loadTexts: docsBpiMIB.setDescription('This is the MIB Module for the DOCSIS Baseline Privacy Interface\n(BPI) at cable modems (CMs) and cable modem termination systems\n(CMTSs). CableLabs requires the implementation of this MIB in\nDOCSIS 1.0 cable modems that implement the Baseline Privacy\nInterface, as a prerequisite for DOCSIS 1.0 certification.')
docsBpiMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 1))
docsBpiCmObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1))
docsBpiCmBaseTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1), )
if mibBuilder.loadTexts: docsBpiCmBaseTable.setDescription('This table describes the basic and authorization-related Baseline\nPrivacy attributes of each CM MAC interface.')
docsBpiCmBaseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: docsBpiCmBaseEntry.setDescription('Each entry contains objects describing attributes of one CM MAC\ninterface. An entry in this table exists for each ifEntry with an\nifType of docsCableMaclayer(127).')
docsBpiCmPrivacyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmPrivacyEnable.setDescription('This object identifies whether this CM is provisioned to run\nBaseline Privacy. This is analogous to the presence (or absence)\nof the Baseline Privacy Configuration Setting option. The status\nof each individual SID with respect to Baseline Privacy is\ncaptured in the docsBpiCmTEKPrivacyEnable object.')
docsBpiCmPublicKey = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 2), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(74,74),ValueSizeConstraint(106,106),ValueSizeConstraint(140,140),ValueSizeConstraint(270,270),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmPublicKey.setDescription('The value of this object is a DER-encoded RSAPublicKey ASN.1 type\nstring, as defined in the RSA Encryption Standard (PKCS #1) [22],\ncorresponding to the public key of the CM. The 74, 106, 140, and\n270 byte key encoding lengths correspond to 512 bit, 768 bit, 1024\nbit, and 2048 public moduli respectively.')
docsBpiCmAuthState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 3), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(2, 3, 4, 5,))).clone(namedValues=NamedValues(("authWait", 2), ("authorized", 3), ("reauthWait", 4), ("authRejectWait", 5),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthState.setDescription('The value of this object is the state of the CM authorization\nFSM.  The start state indicates that FSM is in its initial state.')
docsBpiCmAuthKeySequenceNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthKeySequenceNumber.setDescription('The value of this object is the authorization key sequence number\nfor this FSM.')
docsBpiCmAuthExpires = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 5), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthExpires.setDescription('The value of this object is the actual clock time when the current\nauthorization for this FSM expires. If the CM does not have an active\nauthorization, then the value is of the expiration date and time of\nthe last active authorization.')
docsBpiCmAuthReset = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 6), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmAuthReset.setDescription('Setting this object to TRUE generates a Reauthorize event in the\nauthorization FSM. Reading this object always returns FALSE.')
docsBpiCmAuthGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 7), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthGraceTime.setDescription('The value of this object is the grace time for an authorization key.\nA CM is expected to start trying to get a new authorization key\nbeginning AuthGraceTime seconds before the authorization key actually\nexpires.')
docsBpiCmTEKGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 8), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKGraceTime.setDescription('The value of this object is the grace time for a TEK.  A CM is\nexpected to start trying to get a new TEK beginning TEKGraceTime\nseconds before the TEK actually expires.')
docsBpiCmAuthWaitTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 9), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,30))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthWaitTimeout.setDescription('The value of this object is the Authorize Wait Timeout.')
docsBpiCmReauthWaitTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 10), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,30))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmReauthWaitTimeout.setDescription('The value of this object is the Reauthorize Wait Timeout in seconds.')
docsBpiCmOpWaitTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 11), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmOpWaitTimeout.setDescription('The value of this object is the Operational Wait Timeout in seconds.')
docsBpiCmRekeyWaitTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 12), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,10))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmRekeyWaitTimeout.setDescription('The value of this object is the Rekey Wait Timeout in seconds.')
docsBpiCmAuthRejectWaitTimeout = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 13), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,600))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthRejectWaitTimeout.setDescription('The value of this object is the Authorization Reject Wait Timeout in\nseconds.')
docsBpiCmAuthRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthRequests.setDescription('The value of this object is the count of times the CM has\ntransmitted an Authorization Request message.')
docsBpiCmAuthReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthReplies.setDescription('The value of this object is the count of times the CM has\nreceived an Authorization Reply message.')
docsBpiCmAuthRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 16), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthRejects.setDescription('The value of this object is the count of times the CM has\nreceived an Authorization Reject message.')
docsBpiCmAuthInvalids = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 17), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthInvalids.setDescription('The value of this object is the count of times the CM has\nreceived an Authorization Invalid message.')
docsBpiCmAuthRejectErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 18), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedCm", 3), ("unauthorizedSid", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthRejectErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent Authorization Reject message received by\nthe CM.  This has value unknown(2) if the last Error-Code value was\n0, and none(1) if no Authorization Reject message has been received\nsince reboot.')
docsBpiCmAuthRejectErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 19), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthRejectErrorString.setDescription('The value of this object is the Display-String in most recent\nAuthorization Reject message received by the CM.  This is a zero\nlength string if no Authorization Reject message has been received\nsince reboot.')
docsBpiCmAuthInvalidErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 20), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 5, 6, 7,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedCm", 3), ("unsolicited", 5), ("invalidKeySequence", 6), ("keyRequestAuthenticationFailure", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthInvalidErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent Authorization Invalid message received by\nthe CM.  This has value unknown(2) if the last Error-Code value was\n0, and none(1) if no Authorization Invalid message has been received\nsince reboot.')
docsBpiCmAuthInvalidErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 1, 1, 21), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmAuthInvalidErrorString.setDescription('The value of this object is the Display-String in most recent\nAuthorization Invalid message received by the CM.  This is a zero\nlength string if no Authorization Invalid message has been received\nsince reboot.')
docsBpiCmTEKTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2), )
if mibBuilder.loadTexts: docsBpiCmTEKTable.setDescription('This table describes the attributes of each CM Traffic Encryption Key\n(TEK) association. The CM maintains (no more than) one TEK association\nper SID per CM MAC interface.')
docsBpiCmTEKEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DOCS-IF-MIB", "docsIfCmServiceId"))
if mibBuilder.loadTexts: docsBpiCmTEKEntry.setDescription('Each entry contains objects describing the TEK association attributes\nof one SID. The CM MUST create one entry per unicast SID, regardless\nof whether the SID was obtained from a Registration Response message,\nor from an Authorization Reply message.')
docsBpiCmTEKPrivacyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 1), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKPrivacyEnable.setDescription('This object identifies whether this SID is provisioned to run\nBaseline Privacy. This is analogous to enabling Baseline Privacy on\na provisioned SID using the Class-of-Service Privacy Enable option.\nBaseline Privacy is not effectively enabled for any SID unless\nBaseline Privacy is enabled for the CM, which is managed via the\ndocsBpiCmPrivacyEnable object.')
docsBpiCmTEKState = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 2), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6,))).clone(namedValues=NamedValues(("start", 1), ("opWait", 2), ("opReauthWait", 3), ("operational", 4), ("rekeyWait", 5), ("rekeyReauthWait", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKState.setDescription('The value of this object is the state of the indicated TEK FSM.\nThe start(1) state indicates that FSM is in its initial state.')
docsBpiCmTEKExpiresOld = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKExpiresOld.setDescription('The value of this object is the actual clock time for expiration\nof the immediate predecessor of the most recent TEK for this FSM.\nIf this FSM has only one TEK, then the value is the time of activation\nof this FSM.')
docsBpiCmTEKExpiresNew = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKExpiresNew.setDescription('The value of this object is the actual clock time for expiration\nof the most recent TEK for this FSM.')
docsBpiCmTEKKeyRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKKeyRequests.setDescription('The value of this object is the count of times the CM has transmitted\na Key Request message.')
docsBpiCmTEKKeyReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKKeyReplies.setDescription('The value of this object is the count of times the CM has received\na Key Reply message, including a message whose authentication failed.')
docsBpiCmTEKKeyRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKKeyRejects.setDescription('The value of this object is the count of times the CM has received\na Key Reject message, including a message whose authentication failed.')
docsBpiCmTEKInvalids = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKInvalids.setDescription('The value of this object is the count of times the CM has received\na TEK Invalid message, including a message whose authentication failed.')
docsBpiCmTEKAuthPends = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKAuthPends.setDescription('The value of this object is the count of times an Authorization\nPending (Auth Pend) event occurred in this FSM.')
docsBpiCmTEKKeyRejectErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 4,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedSid", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKKeyRejectErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent Key Reject message received by the CM. This\nhas value unknown(2) if the last Error-Code value was 0, and none(1)\nif no Key Reject message has been received since reboot.')
docsBpiCmTEKKeyRejectErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 11), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKKeyRejectErrorString.setDescription('The value of this object is the Display-String in most recent Key\nReject message received by the CM. This is a zero length string if no\nKey Reject message has been received since reboot.')
docsBpiCmTEKInvalidErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 6,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("invalidKeySequence", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKInvalidErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent TEK Invalid message received by the CM.\nThis has value unknown(2) if the last Error-Code value was 0, and\nnone(1) if no TEK Invalid message has been received since reboot.')
docsBpiCmTEKInvalidErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 1, 2, 1, 13), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmTEKInvalidErrorString.setDescription('The value of this object is the Display-String in most recent TEK\nInvalid message received by the CM. This is a zero length string if\nno TEK Invalid message has been received since reboot.')
docsBpiCmtsObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2))
docsBpiCmtsBaseTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1), )
if mibBuilder.loadTexts: docsBpiCmtsBaseTable.setDescription('This table describes the basic Baseline Privacy attributes of each\nCMTS MAC interface.')
docsBpiCmtsBaseEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"))
if mibBuilder.loadTexts: docsBpiCmtsBaseEntry.setDescription('Each entry contains objects describing attributes of one CMTS MAC\ninterface. An entry in this table exists for each ifEntry with an\nifType of docsCableMaclayer(127).')
docsBpiCmtsDefaultAuthLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,6048000))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsDefaultAuthLifetime.setDescription('The value of this object is the default lifetime, in seconds, the\nCMTS assigns to a new authorization key.')
docsBpiCmtsDefaultTEKLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,604800))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsDefaultTEKLifetime.setDescription('The value of this object is the default lifetime, in seconds, the\nCMTS assigns to a new Traffic Encryption Key (TEK).')
docsBpiCmtsDefaultAuthGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsDefaultAuthGraceTime.setDescription('This object was obsoleted because the provisioning system, not the CMTS,\nmanages the authorization key grace time for DOCSIS CMs.')
docsBpiCmtsDefaultTEKGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsDefaultTEKGraceTime.setDescription('This object was obsoleted because the provisioning system, not the CMTS,\nmanages the Traffic Encryption Key (TEK) grace time for DOCSIS CMs.')
docsBpiCmtsAuthRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthRequests.setDescription('The value of this object is the count of times the CMTS has\nreceived an Authorization Request message from any CM.')
docsBpiCmtsAuthReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthReplies.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Reply message to any CM.')
docsBpiCmtsAuthRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthRejects.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Reject message to any CM.')
docsBpiCmtsAuthInvalids = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 1, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthInvalids.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Invalid message to any CM.')
docsBpiCmtsAuthTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2), )
if mibBuilder.loadTexts: docsBpiCmtsAuthTable.setDescription('This table describes the attributes of each CM authorization\nassociation. The CMTS maintains one authorization association with\neach Baseline Privacy-enabled CM on each CMTS MAC interface.')
docsBpiCmtsAuthEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DOCS-BPI-MIB", "docsBpiCmtsAuthCmMacAddress"))
if mibBuilder.loadTexts: docsBpiCmtsAuthEntry.setDescription('Each entry contains objects describing attributes of one\nauthorization association. The CMTS MUST create one entry per CM per\nMAC interface, based on the receipt of an Authorization Request\nmessage, and MUST not delete the entry before the CM authorization\npermanently expires.')
docsBpiCmtsAuthCmMacAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 1), MacAddress())
if mibBuilder.loadTexts: docsBpiCmtsAuthCmMacAddress.setDescription('The value of this object is the physical address of the CM to\nwhich the authorization association applies.')
docsBpiCmtsAuthCmPublicKey = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 2), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(74,74),ValueSizeConstraint(106,106),ValueSizeConstraint(140,140),ValueSizeConstraint(270,270),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmPublicKey.setDescription('The value of this object is a DER-encoded RSAPublicKey ASN.1 type\nstring, as defined in the RSA Encryption Standard (PKCS #1) [22],\ncorresponding to the public key of the CM. The 74, 106, 140, and\n270 byte key encoding lengths correspond to 512 bit, 768 bit, 1024\nbit, and 2048 public moduli respectively. This is a zero-length\nstring if the CMTS does not retain the public key.')
docsBpiCmtsAuthCmKeySequenceNumber = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,15))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmKeySequenceNumber.setDescription('The value of this object is the authorization key sequence number\nfor this CM.')
docsBpiCmtsAuthCmExpires = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmExpires.setDescription('The value of this object is the actual clock time when the current\nauthorization for this CM expires. If this CM does not have an\nactive authorization, then the value is of the expiration date and\ntime of the last active authorization.')
docsBpiCmtsAuthCmLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 5), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,6048000))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmLifetime.setDescription('The value of this object is the lifetime, in seconds, the CMTS\nassigns to an authorization key for this CM.')
docsBpiCmtsAuthCmGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 6), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmGraceTime.setDescription('The value of this object is the grace time for the authorization key\nin seconds.  The CM is expected to start trying to get a new\nauthorization key beginning AuthGraceTime seconds before the\nauthorization key actually expires.')
docsBpiCmtsAuthCmReset = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 7), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("noResetRequested", 1), ("invalidateAuth", 2), ("sendAuthInvalid", 3), ("invalidateTeks", 4),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmReset.setDescription('Setting this object to invalidateAuth(2) causes the CMTS to\ninvalidate the current CM authorization key, but not to transmit an\nAuthorization Invalid message nor to invalidate unicast TEKs.  Setting\nthis object to sendAuthInvalid(3) causes the CMTS to invalidate the\ncurrent CM authorization key, and to transmit an Authorization Invalid\nmessage to the CM, but not to invalidate unicast TEKs.  Setting this\nobject to invalidateTeks(4) causes the CMTS to invalidate the current\nCM authorization key, to transmit an Authorization Invalid message to\nthe CM, and to invalidate all unicast TEKs associated with this CM\nauthorization. Reading this object returns the most-recently-set value\nof this object, or returns noResetRequested(1) if the object has not\nbeen set since the last CMTS reboot.')
docsBpiCmtsAuthCmRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmRequests.setDescription('The value of this object is the count of times the CMTS has\nreceived an Authorization Request message from this CM.')
docsBpiCmtsAuthCmReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmReplies.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Reply message to this CM.')
docsBpiCmtsAuthCmRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 10), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmRejects.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Reject message to this CM.')
docsBpiCmtsAuthCmInvalids = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 11), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthCmInvalids.setDescription('The value of this object is the count of times the CMTS has\ntransmitted an Authorization Invalid message to this CM.')
docsBpiCmtsAuthRejectErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedCm", 3), ("unauthorizedSid", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthRejectErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent Authorization Reject message transmitted to\nthe CM.  This has value unknown(2) if the last Error-Code value was\n0, and none(1) if no Authorization Reject message has been transmitted\nto the CM.')
docsBpiCmtsAuthRejectErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 13), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthRejectErrorString.setDescription('The value of this object is the Display-String in most recent\nAuthorization Reject message transmitted to the CM.  This is a\nzero length string if no Authorization Reject message has been\ntransmitted to the CM.')
docsBpiCmtsAuthInvalidErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 14), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 5, 6, 7,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedCm", 3), ("unsolicited", 5), ("invalidKeySequence", 6), ("keyRequestAuthenticationFailure", 7),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthInvalidErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in most recent Authorization Invalid message transmitted\nto the CM.  This has value unknown(2) if the last Error-Code value was\n0, and none(1) if no Authorization Invalid message has been\ntransmitted to the CM.')
docsBpiCmtsAuthInvalidErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 2, 1, 15), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsAuthInvalidErrorString.setDescription('The value of this object is the Display-String in most recent\nAuthorization Invalid message transmitted to the CM.  This is a\nzero length string if no Authorization Invalid message has been\ntransmitted to the CM.')
docsBpiCmtsTEKTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3), )
if mibBuilder.loadTexts: docsBpiCmtsTEKTable.setDescription('This table describes the attributes of each CM Traffic Encryption\nKey (TEK) association. The CMTS maintains one TEK association per BPI\nSID on each CMTS MAC interface.')
docsBpiCmtsTEKEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DOCS-IF-MIB", "docsIfCmtsServiceId"))
if mibBuilder.loadTexts: docsBpiCmtsTEKEntry.setDescription('Each entry contains objects describing attributes of one TEK\nassociation on a particular CMTS MAC interface. The CMTS MUST create\none entry per SID per MAC interface, based on the receipt of an\nKey Request message, and MUST not delete the entry before the CM\nauthorization for the SID permanently expires.')
docsBpiCmtsTEKLifetime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,604800))).setUnits('seconds').setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsTEKLifetime.setDescription('The value of this object is the lifetime, in seconds, the CMTS assigns\nto keys for this TEK association.')
docsBpiCmtsTEKGraceTime = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(1,1800))).setUnits('seconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKGraceTime.setDescription('The value of this object is the grace time for the TEK in seconds.\nThe CM is expected to start trying to get a new TEK beginning\nTEKGraceTime seconds before the TEK actually expires.')
docsBpiCmtsTEKExpiresOld = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 3), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKExpiresOld.setDescription('The value of this object is the actual clock time for expiration\nof the immediate predecessor of the most recent TEK for this FSM.\nIf this FSM has only one TEK, then the value is the time of activation\nof this FSM.')
docsBpiCmtsTEKExpiresNew = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 4), DateAndTime()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKExpiresNew.setDescription('The value of this object is the actual clock time for expiration\nof the most recent TEK for this FSM.')
docsBpiCmtsTEKReset = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 5), TruthValue()).setMaxAccess("readwrite")
if mibBuilder.loadTexts: docsBpiCmtsTEKReset.setDescription('Setting this object to TRUE causes the CMTS to invalidate the current\nactive TEK(s) (plural due to key transition periods), and to generate\na new TEK for the associated SID; the CMTS MAY also generate an\nunsolicited TEK Invalid message, to optimize the TEK synchronization\nbetween the CMTS and the CM. Reading this object always returns\nFALSE.')
docsBpiCmtsKeyRequests = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsKeyRequests.setDescription('The value of this object is the count of times the CMTS has\nreceived a Key Request message.')
docsBpiCmtsKeyReplies = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsKeyReplies.setDescription('The value of this object is the count of times the CMTS has\ntransmitted a Key Reply message.')
docsBpiCmtsKeyRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 8), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsKeyRejects.setDescription('The value of this object is the count of times the CMTS has\ntransmitted a Key Reject message.')
docsBpiCmtsTEKInvalids = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 9), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKInvalids.setDescription('The value of this object is the count of times the CMTS has\ntransmitted a TEK Invalid message.')
docsBpiCmtsKeyRejectErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 10), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 4,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("unauthorizedSid", 4),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsKeyRejectErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in the most recent Key Reject message sent in response to\na Key Request for this BPI SID. This has value unknown(2) if the last\nError-Code value was 0, and none(1) if no Key Reject message has been\nreceived since reboot.')
docsBpiCmtsKeyRejectErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 11), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsKeyRejectErrorString.setDescription('The value of this object is the Display-String in the most recent\nKey Reject message sent in response to a Key Request for this BPI\nSID.  This is a zero length string if no Key Reject message has been\nreceived since reboot.')
docsBpiCmtsTEKInvalidErrorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 12), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 6,))).clone(namedValues=NamedValues(("none", 1), ("unknown", 2), ("invalidKeySequence", 6),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKInvalidErrorCode.setDescription('The value of this object is the enumerated description of the\nError-Code in the most recent TEK Invalid message sent in association\nwith this BPI SID.  This has value unknown(2) if the last Error-Code\nvalue was 0, and none(1) if no TEK Invalid message has been received\nsince reboot.')
docsBpiCmtsTEKInvalidErrorString = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 3, 1, 13), DisplayString().subtype(subtypeSpec=ValueSizeConstraint(0,128))).setMaxAccess("readonly")
if mibBuilder.loadTexts: docsBpiCmtsTEKInvalidErrorString.setDescription('The value of this object is the Display-String in the most recent TEK\nInvalid message sent in association with this BPI SID.  This is a zero\nlength string if no TEK Invalid message has been received since reboot.')
docsBpiMulticastControl = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4))
docsBpiIpMulticastMapTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1), )
if mibBuilder.loadTexts: docsBpiIpMulticastMapTable.setDescription('This table describes the mapping of IP multicast address prefixes to\nmulticast SIDs on each CMTS MAC interface.')
docsBpiIpMulticastMapEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DOCS-BPI-MIB", "docsBpiIpMulticastAddress"), (0, "DOCS-BPI-MIB", "docsBpiIpMulticastPrefixLength"))
if mibBuilder.loadTexts: docsBpiIpMulticastMapEntry.setDescription('Each entry contains objects describing the mapping of one IP\nmulticast address prefix to one multicast SID on one CMTS MAC\ninterface. The CMTS uses the mapping when forwarding downstream IP\nmulticast traffic.')
docsBpiIpMulticastAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1, 1, 1), IpAddress())
if mibBuilder.loadTexts: docsBpiIpMulticastAddress.setDescription('This object represents the IP multicast address (prefix) to be\nmapped by this row, in conjunction with\ndocsBpiIpMulticastPrefixLength.')
docsBpiIpMulticastPrefixLength = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1, 1, 2), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,32)))
if mibBuilder.loadTexts: docsBpiIpMulticastPrefixLength.setDescription('This object represents the IP multicast address prefix length\nfor this row. The value of this object represents the length in\nbits of docsBpiIpMulticastAddress for multicast address\ncomparisons, using big-endian ordering. An IP multicast address\nmatches this row if the (docsBpiIpMulticastPrefixLength) most\nsignificant bits of the IP multicast address and of the\n(docsBpiIpMulticastAddress) are identical.\nThis object is similar in usage to an IP address mask. The value\n0 corresponds to IP address mask 0.0.0.0, the value 1 corresponds\nto IP address mask 128.0.0.0, the value 8 corresponds to IP\naddress mask 255.0.0.0, and the value 32 corresponds to IP\naddress mask 255.255.255.255.')
docsBpiIpMulticastServiceId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1, 1, 3), Integer32().subtype(subtypeSpec=ValueRangeConstraint(8192,16368))).setMaxAccess("readcreate")
if mibBuilder.loadTexts: docsBpiIpMulticastServiceId.setDescription('This object represents the multicast SID to be used in this\nIP multicast address prefix mapping entry.')
docsBpiIpMulticastMapControl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 1, 1, 4), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: docsBpiIpMulticastMapControl.setDescription('This object controls and reflects the IP multicast address prefix\nmapping entry. There is no restriction on the ability to change values\nin this row while the row is active.')
docsBpiMulticastAuthTable = MibTable((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 2), )
if mibBuilder.loadTexts: docsBpiMulticastAuthTable.setDescription('This table describes the multicast SID authorization for each\nCM on each CMTS MAC interface.')
docsBpiMulticastAuthEntry = MibTableRow((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 2, 1), ).setIndexNames((0, "IF-MIB", "ifIndex"), (0, "DOCS-BPI-MIB", "docsBpiMulticastServiceId"), (0, "DOCS-BPI-MIB", "docsBpiMulticastCmMacAddress"))
if mibBuilder.loadTexts: docsBpiMulticastAuthEntry.setDescription('Each entry contains objects describing the key authorization of one\ncable modem for one multicast SID for one CMTS MAC interface.')
docsBpiMulticastServiceId = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 2, 1, 1), Integer32().subtype(subtypeSpec=ValueRangeConstraint(8192,16368)))
if mibBuilder.loadTexts: docsBpiMulticastServiceId.setDescription('This object represents the multicast SID for authorization.')
docsBpiMulticastCmMacAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 2, 1, 2), MacAddress())
if mibBuilder.loadTexts: docsBpiMulticastCmMacAddress.setDescription('This object represents the MAC address of the CM to which the\nmulticast SID authorization applies.')
docsBpiMulticastAuthControl = MibTableColumn((1, 3, 6, 1, 2, 1, 10, 127, 5, 1, 2, 4, 2, 1, 3), RowStatus()).setMaxAccess("readcreate")
if mibBuilder.loadTexts: docsBpiMulticastAuthControl.setDescription('This object controls and reflects the CM authorization for each\nmulticast SID. There is no restriction on the ability to change\nvalues in this row while the row is active.')
docsBpiNotification = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 2))
docsBpiConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 3))
docsBpiCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 1))
docsBpiGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 2))
docsBpiBasicCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 1, 1)).setObjects(*(("DOCS-BPI-MIB", "docsBpiCmGroup"), ("DOCS-BPI-MIB", "docsBpiCmtsGroup"),))
if mibBuilder.loadTexts: docsBpiBasicCompliance.setDescription('This is the compliance statement for devices which implement the\nDOCSIS Baseline Privacy Interface.')
docsBpiCmGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 2, 1)).setObjects(*(("DOCS-BPI-MIB", "docsBpiCmPrivacyEnable"), ("DOCS-BPI-MIB", "docsBpiCmPublicKey"), ("DOCS-BPI-MIB", "docsBpiCmAuthState"), ("DOCS-BPI-MIB", "docsBpiCmAuthKeySequenceNumber"), ("DOCS-BPI-MIB", "docsBpiCmAuthExpires"), ("DOCS-BPI-MIB", "docsBpiCmAuthReset"), ("DOCS-BPI-MIB", "docsBpiCmAuthGraceTime"), ("DOCS-BPI-MIB", "docsBpiCmTEKGraceTime"), ("DOCS-BPI-MIB", "docsBpiCmAuthWaitTimeout"), ("DOCS-BPI-MIB", "docsBpiCmReauthWaitTimeout"), ("DOCS-BPI-MIB", "docsBpiCmOpWaitTimeout"), ("DOCS-BPI-MIB", "docsBpiCmRekeyWaitTimeout"), ("DOCS-BPI-MIB", "docsBpiCmAuthRejectWaitTimeout"), ("DOCS-BPI-MIB", "docsBpiCmAuthRequests"), ("DOCS-BPI-MIB", "docsBpiCmAuthReplies"), ("DOCS-BPI-MIB", "docsBpiCmAuthRejects"), ("DOCS-BPI-MIB", "docsBpiCmAuthInvalids"), ("DOCS-BPI-MIB", "docsBpiCmAuthRejectErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmAuthRejectErrorString"), ("DOCS-BPI-MIB", "docsBpiCmAuthInvalidErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmAuthInvalidErrorString"), ("DOCS-BPI-MIB", "docsBpiCmTEKPrivacyEnable"), ("DOCS-BPI-MIB", "docsBpiCmTEKState"), ("DOCS-BPI-MIB", "docsBpiCmTEKExpiresOld"), ("DOCS-BPI-MIB", "docsBpiCmTEKExpiresNew"), ("DOCS-BPI-MIB", "docsBpiCmTEKKeyRequests"), ("DOCS-BPI-MIB", "docsBpiCmTEKKeyReplies"), ("DOCS-BPI-MIB", "docsBpiCmTEKKeyRejects"), ("DOCS-BPI-MIB", "docsBpiCmTEKInvalids"), ("DOCS-BPI-MIB", "docsBpiCmTEKAuthPends"), ("DOCS-BPI-MIB", "docsBpiCmTEKKeyRejectErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmTEKKeyRejectErrorString"), ("DOCS-BPI-MIB", "docsBpiCmTEKInvalidErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmTEKInvalidErrorString"),))
if mibBuilder.loadTexts: docsBpiCmGroup.setDescription('This collection of objects provides CM BPI status and control.')
docsBpiCmtsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 2, 2)).setObjects(*(("DOCS-BPI-MIB", "docsBpiCmtsDefaultAuthLifetime"), ("DOCS-BPI-MIB", "docsBpiCmtsDefaultTEKLifetime"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthRequests"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthReplies"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthRejects"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthInvalids"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmPublicKey"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmKeySequenceNumber"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmExpires"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmLifetime"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmGraceTime"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmReset"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmRequests"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmReplies"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmRejects"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthCmInvalids"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthRejectErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthRejectErrorString"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthInvalidErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmtsAuthInvalidErrorString"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKLifetime"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKGraceTime"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKExpiresOld"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKExpiresNew"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKReset"), ("DOCS-BPI-MIB", "docsBpiCmtsKeyRequests"), ("DOCS-BPI-MIB", "docsBpiCmtsKeyReplies"), ("DOCS-BPI-MIB", "docsBpiCmtsKeyRejects"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKInvalids"), ("DOCS-BPI-MIB", "docsBpiCmtsKeyRejectErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmtsKeyRejectErrorString"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKInvalidErrorCode"), ("DOCS-BPI-MIB", "docsBpiCmtsTEKInvalidErrorString"), ("DOCS-BPI-MIB", "docsBpiIpMulticastServiceId"), ("DOCS-BPI-MIB", "docsBpiIpMulticastMapControl"), ("DOCS-BPI-MIB", "docsBpiMulticastAuthControl"),))
if mibBuilder.loadTexts: docsBpiCmtsGroup.setDescription('This collection of objects provides CMTS BPI status and control.')
docsBpiObsoleteObjectsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 10, 127, 5, 3, 2, 3)).setObjects(*(("DOCS-BPI-MIB", "docsBpiCmtsDefaultAuthGraceTime"), ("DOCS-BPI-MIB", "docsBpiCmtsDefaultTEKGraceTime"),))
if mibBuilder.loadTexts: docsBpiObsoleteObjectsGroup.setDescription('This is a collection of obsolete BPI objects.')
mibBuilder.exportSymbols("DOCS-BPI-MIB", docsBpiIpMulticastMapTable=docsBpiIpMulticastMapTable, docsBpiCmAuthReset=docsBpiCmAuthReset, docsBpiCmAuthRequests=docsBpiCmAuthRequests, docsBpiCmTEKAuthPends=docsBpiCmTEKAuthPends, docsBpiCmGroup=docsBpiCmGroup, docsBpiCmTEKTable=docsBpiCmTEKTable, docsBpiMulticastCmMacAddress=docsBpiMulticastCmMacAddress, docsBpiMulticastAuthEntry=docsBpiMulticastAuthEntry, docsBpiCmPrivacyEnable=docsBpiCmPrivacyEnable, docsBpiCmtsAuthCmMacAddress=docsBpiCmtsAuthCmMacAddress, docsBpiCmtsAuthReplies=docsBpiCmtsAuthReplies, docsBpiCmtsAuthInvalids=docsBpiCmtsAuthInvalids, docsBpiCmAuthRejectErrorString=docsBpiCmAuthRejectErrorString, docsBpiBasicCompliance=docsBpiBasicCompliance, docsBpiCmtsTEKInvalidErrorCode=docsBpiCmtsTEKInvalidErrorCode, docsBpiCmtsKeyRequests=docsBpiCmtsKeyRequests, docsBpiCmtsDefaultAuthGraceTime=docsBpiCmtsDefaultAuthGraceTime, docsBpiCmtsKeyReplies=docsBpiCmtsKeyReplies, docsBpiCmtsAuthCmInvalids=docsBpiCmtsAuthCmInvalids, docsBpiCmAuthWaitTimeout=docsBpiCmAuthWaitTimeout, docsBpiCmtsTEKLifetime=docsBpiCmtsTEKLifetime, docsBpiMIB=docsBpiMIB, docsBpiCmtsTEKInvalidErrorString=docsBpiCmtsTEKInvalidErrorString, docsBpiCmAuthInvalidErrorCode=docsBpiCmAuthInvalidErrorCode, docsBpiCmAuthInvalids=docsBpiCmAuthInvalids, docsBpiCmtsTEKEntry=docsBpiCmtsTEKEntry, docsBpiNotification=docsBpiNotification, docsBpiCmTEKPrivacyEnable=docsBpiCmTEKPrivacyEnable, docsBpiMulticastControl=docsBpiMulticastControl, docsBpiCmAuthGraceTime=docsBpiCmAuthGraceTime, docsBpiCmtsAuthCmGraceTime=docsBpiCmtsAuthCmGraceTime, docsBpiCmTEKInvalidErrorCode=docsBpiCmTEKInvalidErrorCode, docsBpiCmAuthKeySequenceNumber=docsBpiCmAuthKeySequenceNumber, docsBpiCmTEKGraceTime=docsBpiCmTEKGraceTime, docsBpiCmtsAuthRejectErrorCode=docsBpiCmtsAuthRejectErrorCode, docsBpiCmtsAuthCmRequests=docsBpiCmtsAuthCmRequests, docsBpiCmtsTEKExpiresOld=docsBpiCmtsTEKExpiresOld, docsBpiCmtsAuthInvalidErrorCode=docsBpiCmtsAuthInvalidErrorCode, docsBpiCmtsTEKExpiresNew=docsBpiCmtsTEKExpiresNew, docsBpiCmtsDefaultTEKGraceTime=docsBpiCmtsDefaultTEKGraceTime, docsBpiCmtsAuthInvalidErrorString=docsBpiCmtsAuthInvalidErrorString, docsBpiCmtsAuthRejectErrorString=docsBpiCmtsAuthRejectErrorString, docsBpiCmtsAuthCmLifetime=docsBpiCmtsAuthCmLifetime, docsBpiCmTEKKeyRejectErrorCode=docsBpiCmTEKKeyRejectErrorCode, docsBpiCmtsDefaultTEKLifetime=docsBpiCmtsDefaultTEKLifetime, docsBpiCmRekeyWaitTimeout=docsBpiCmRekeyWaitTimeout, docsBpiCmtsAuthEntry=docsBpiCmtsAuthEntry, docsBpiMulticastAuthTable=docsBpiMulticastAuthTable, docsBpiIpMulticastMapEntry=docsBpiIpMulticastMapEntry, docsBpiCmtsBaseEntry=docsBpiCmtsBaseEntry, docsBpiObsoleteObjectsGroup=docsBpiObsoleteObjectsGroup, docsBpiIpMulticastPrefixLength=docsBpiIpMulticastPrefixLength, docsBpiMIBObjects=docsBpiMIBObjects, docsBpiCmTEKKeyRequests=docsBpiCmTEKKeyRequests, docsBpiCmTEKInvalidErrorString=docsBpiCmTEKInvalidErrorString, docsBpiCmAuthRejects=docsBpiCmAuthRejects, docsBpiCmtsKeyRejectErrorCode=docsBpiCmtsKeyRejectErrorCode, docsBpiCompliances=docsBpiCompliances, docsBpiCmAuthRejectErrorCode=docsBpiCmAuthRejectErrorCode, docsBpiCmTEKEntry=docsBpiCmTEKEntry, docsBpiCmObjects=docsBpiCmObjects, docsBpiIpMulticastServiceId=docsBpiIpMulticastServiceId, docsBpiCmTEKKeyRejects=docsBpiCmTEKKeyRejects, docsBpiCmtsAuthCmReplies=docsBpiCmtsAuthCmReplies, docsBpiCmTEKKeyReplies=docsBpiCmTEKKeyReplies, docsBpiMulticastServiceId=docsBpiMulticastServiceId, docsBpiCmtsKeyRejectErrorString=docsBpiCmtsKeyRejectErrorString, docsBpiIpMulticastAddress=docsBpiIpMulticastAddress, PYSNMP_MODULE_ID=docsBpiMIB, docsBpiCmAuthRejectWaitTimeout=docsBpiCmAuthRejectWaitTimeout, docsBpiCmtsTEKGraceTime=docsBpiCmtsTEKGraceTime, docsBpiCmtsAuthCmPublicKey=docsBpiCmtsAuthCmPublicKey, docsBpiCmtsAuthCmReset=docsBpiCmtsAuthCmReset, docsBpiConformance=docsBpiConformance, docsBpiCmtsAuthCmRejects=docsBpiCmtsAuthCmRejects, docsBpiCmAuthInvalidErrorString=docsBpiCmAuthInvalidErrorString, docsBpiCmAuthExpires=docsBpiCmAuthExpires, docsBpiCmReauthWaitTimeout=docsBpiCmReauthWaitTimeout, docsBpiCmtsAuthCmExpires=docsBpiCmtsAuthCmExpires, docsBpiCmtsDefaultAuthLifetime=docsBpiCmtsDefaultAuthLifetime, docsBpiCmtsBaseTable=docsBpiCmtsBaseTable, docsBpiCmtsObjects=docsBpiCmtsObjects, docsBpiCmTEKExpiresNew=docsBpiCmTEKExpiresNew, docsBpiCmtsAuthRejects=docsBpiCmtsAuthRejects, docsBpiCmtsTEKInvalids=docsBpiCmtsTEKInvalids, docsBpiCmtsAuthTable=docsBpiCmtsAuthTable, docsBpiCmOpWaitTimeout=docsBpiCmOpWaitTimeout, docsBpiCmTEKKeyRejectErrorString=docsBpiCmTEKKeyRejectErrorString, docsBpiCmPublicKey=docsBpiCmPublicKey, docsBpiCmTEKInvalids=docsBpiCmTEKInvalids, docsBpiCmtsTEKTable=docsBpiCmtsTEKTable, docsBpiCmAuthReplies=docsBpiCmAuthReplies, docsBpiCmtsKeyRejects=docsBpiCmtsKeyRejects, docsBpiGroups=docsBpiGroups, docsBpiCmAuthState=docsBpiCmAuthState, docsBpiCmBaseEntry=docsBpiCmBaseEntry, docsBpiCmtsAuthCmKeySequenceNumber=docsBpiCmtsAuthCmKeySequenceNumber, docsBpiMulticastAuthControl=docsBpiMulticastAuthControl, docsBpiIpMulticastMapControl=docsBpiIpMulticastMapControl, docsBpiCmBaseTable=docsBpiCmBaseTable, docsBpiCmTEKState=docsBpiCmTEKState, docsBpiCmtsGroup=docsBpiCmtsGroup, docsBpiCmTEKExpiresOld=docsBpiCmTEKExpiresOld, docsBpiCmtsTEKReset=docsBpiCmtsTEKReset, docsBpiCmtsAuthRequests=docsBpiCmtsAuthRequests)
